| Title: | Content to Support Classes Taught Through the Open Visualization Academy |
|---|---|
| Description: | This contains functions and data used by the Open Visualization Academy classes on data processing and visualization. The tutorial included with this package requires the 'gradethis' package which can be installed using "remotes::install_github('rstudio/gradethis')". |
| Authors: | Raymond Balise [aut, cre] (ORCID: <https://orcid.org/0000-0002-9856-5901>), Kyle Grealis [aut] (ORCID: <https://orcid.org/0000-0002-9223-8854>), Ricky Lei [ctb] (ORCID: <https://orcid.org/0000-0003-1953-9236>), Gabriel Odom [ctb] (ORCID: <https://orcid.org/0000-0003-1341-4555>) |
| Maintainer: | Raymond Balise <[email protected]> |
| License: | AGPL (>= 3) |
| Version: | 1.0.0 |
| Built: | 2026-05-22 06:00:17 UTC |
| Source: | https://github.com/raymondbalise/open.visualization.academy |
This dataset, which is ready for analysis, was created by setting the variable types, specifying factor levels instead of code numbers, and applying labels to the laryngectomy dataset. It includes demographics, surgery details, and outcomes for 123 individuals who underwent a laryngectomy at an unspecified medical center between 2000 and 2012.
analysisanalysis
A labelled tibble with 123 rows and 33 variables:
| Type: | integer |
| Description: | Age in years |
| Type: | factor (First/Reference level = Male) |
| Description: | Sex assigned at Birth |
| Levels: | Male, Female
|
| Type: | factor (First/Reference level = Supra) |
| Description: | Recurrent Site |
| Levels: | Supra, Glottic, Transglottic, Unknown
|
| Type: | factor (First/Reference level = XRT) |
| Description: | Treatment Modality |
| Levels: | XRT, Chemo+XRT, Unspecified
|
| Type: | ordered (First/Reference level = Unknown) |
| Description: | Initial Stage |
| Levels: | Unknown, T1, T2, T3, T4
|
| Type: | ordered (First/Reference level = Unknown) |
| Description: | Recurrent staging |
| Levels: | Unknown, T1, T2, T3, T4
|
| Type: | factor (First/Reference level = CT) |
| Description: | Imaging |
| Levels: | CT, PET, CT+PET, MRI
|
| Type: | factor (First/Reference level = Yes) |
| Description: | Neck Dissection |
| Levels: | Yes, No
|
| Type: | factor (First/Reference level = Bilateral) |
| Description: | Laterality |
| Levels: | Bilateral, Unilateral
|
| Type: | factor (First/Reference level = Yes) |
| Description: | Microvascular Flap |
| Levels: | Yes, No
|
| Type: | factor (First/Reference level = Yes) |
| Description: | Pectoralis major myocutaneous flap |
| Levels: | Yes, No
|
| Type: | factor (First/Reference level = Positive) |
| Description: | Nodal Pathology evaluation of specimen |
| Levels: | Positive, Negative
|
| Type: | ordered (First/Reference level = Unknown) |
| Description: | Pathologic staging |
| Levels: | Unknown, T1, T2, T3, T4
|
| Type: | factor (First/Reference level = Yes) |
| Description: | Complications |
| Levels: | Yes, No
|
| Type: | factor (First/Reference level = Yes) |
| Description: | Salivary fistula or leak |
| Levels: | Yes, No
|
| Type: | factor (First/Reference level = Yes) |
| Description: | Wound Infection |
| Levels: | Yes, No
|
| Type: | factor (First/Reference level = Yes) |
| Description: | Wound dehiscence |
| Levels: | Yes, No
|
| Type: | factor (First/Reference level = Yes) |
| Description: | Wound Complications |
| Levels: | Yes, No
|
| Type: | factor (First/Reference level = Yes) |
| Description: | Chyle leak |
| Levels: | Yes, No
|
| Type: | factor (First/Reference level = Yes) |
| Description: | Hematoma |
| Levels: | Yes, No
|
| Type: | factor (First/Reference level = Yes) |
| Description: | Revision procedure |
| Levels: | Yes, No
|
| Type: | factor (First/Reference level = Yes) |
| Description: | Flap Failure |
| Levels: | Yes, No
|
| Type: | factor (First/Reference level = Yes) |
| Description: | Perioperative Death |
| Levels: | Yes, No
|
| Type: | factor (First/Reference level = Yes) |
| Description: | Medical Complications |
| Levels: | Yes, No
|
| Type: | factor (First/Reference level = Yes) |
| Description: | 2 or more complications |
| Levels: | Yes, No
|
| Type: | integer |
| Description: | Hospital Stay |
| Type: | factor (First/Reference level = Yes) |
| Description: | Death status |
| Levels: | Yes, No
|
| Type: | factor (First/Reference level = Yes) |
| Description: | Recurrence status |
| Levels: | Yes, No
|
| Type: | factor (First/Reference level = No recurrence) |
| Description: | Site of Recurrence after salvage laryngectomy |
| Levels: | No recurrence, Local/regional, Distant
|
| Type: | integer |
| Description: | Days of follow-up |
| Type: | integer |
| Description: | Days until death |
| Type: | integer |
| Description: | Days until recurrence |
| Type: | integer |
| Description: | Number of complications |
A dataset containing demographics and surgery details and outcomes on 123 people who underwent laryngectomy at an unspecified medical center between 2000 and 2012.
laryngectomylaryngectomy
A tibble with 123 rows and 32 variables:
Age in years with 90+ removed
sex (M=1, F=2)
Recurrent Site (Supra=1, Glottic=2, Transglottic=3, Unknown=4)
Treatment Modality (XRT=1 Chemo+XRT=2 Unspecified=3)
Initial Stage (T1=1, T2=2, T3=3, T4=4 Unknown=5)
Recurrent staging (T1=1, T2=2, T3=3, T4=4, unknown=5)
Imaging (CT=1 PET=2 CT+PET=3 MRI=4)
Neck Dissection (Yes=1, No=2)
Laterality (Bilateral Neck Dissection=1, Unilateral Neck Dissection=2)
Microvascular Flap (Yes=1, No=2)
Pectoralis major myocutaneous flap (Yes=1, No=2)
Nodal Pathology evaluation of specimen (Positive=1, Negative=2)
Pathologic staging (T1=1, T2=2, T3=3, T4=4, unknown=5)
Complications (Yes=1, No=2)
Salivary fistula or leak (Yes=1, No=2)
Wound Infection (Yes=1, No=2)
Wound dehiscence (Yes=1, No=2)
Wound Complications (Yes=1, No=2)
Chyle leak (Yes=1, No=2)
Hematoma (Yes=1, No=2)
Revision procedure (Yes=1, No=2)
Flap Failure (Yes=1, No=2)
Perioperative Death (Yes=1, No=2)
Medical Complications (Yes=1, No=2)
2 or more complications (Yes=1, No=2)
Hospital Stay (<7 days=1, 7-14 days=2, >14 days)
Death status (Dead=1 Alive=2)
Recurrence status (Recurred=1, No recurrence=2)
Site of Recurrence after salvage laryngectomy (Locoregional=1, Distant=3, No recurrence=0)
Days of follow-up
Days until death
Days until recurrence
This function prints the name of a dataset and then details on its variables. Run this, then check the output to make sure it does not show any sensitive information. If it does not, paste it into your favorite AI's chat box to help it understand the problem you are solving.
show_structure(data, display_redacted = FALSE, clipboard = TRUE)show_structure(data, display_redacted = FALSE, clipboard = TRUE)
data |
|
display_redacted |
|
clipboard |
|
A formatted markdown table (via knitr::kable) displaying the structure of the input dataset. The table contains three columns:
variable |
Column names from the input data |
type |
Data type of each column (e.g., "numeric", "factor", "Date") |
levels |
For factors: comma-separated factor levels; for numeric/integer: value range; for other types: NA |
show_structure(mtcars)show_structure(mtcars)